@@ -1,13 +1,15 @@
 package Perinci::Sub::Property::memoize;
 
+our $DATE = '2016-03-10'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
+use Data::Dmp;
 use Perinci::Sub::PropertyUtil qw(declare_property);
 
-our $VERSION = '0.02'; # VERSION
-
 declare_property(
     name => 'memoize',
     type => 'function',
@@ -33,12 +35,12 @@ declare_property(
             $self->select_section('declare_vars');
             $self->_add_var('_w_cache_key');
             my @fargs_names = sort keys %{ $self->{_meta}{args} // {} };
-            my $qsub_name = Perinci::Sub::Wrapper::__squote($self->{_args}{sub_name});
+            my $qsub_name = dmp($self->{_args}{sub_name});
             $self->push_lines(
                 '{',
                 '    no warnings;',
                 '    $_w_cache_key = join("\0", map {$args{$_}} ('.
-                    join(",",map {Perinci::Sub::Wrapper::__squote($_)}
+                    join(",",map {dmp($_)}
                              @fargs_names).'));',
                 '    return $Perinci::Sub::Wrapped::memoize_cache{'.$qsub_name.'}{$_w_cache_key} '.
                     'if exists $Perinci::Sub::Wrapped::memoize_cache{'.$qsub_name.'}{$_w_cache_key};',
@@ -68,7 +70,7 @@ Perinci::Sub::Property::memoize - Memoize function
 
 =head1 VERSION
 
-This document describes version 0.02 of Perinci::Sub::Property::memoize (from Perl distribution Perinci-Sub-Property-memoize), released on 2015-02-05.
+This document describes version 0.03 of Perinci::Sub::Property::memoize (from Perl distribution Perinci-Sub-Property-memoize), released on 2016-03-10.
 
 =head1 SYNOPSIS
 
@@ -81,12 +83,6 @@ This property implements a simple memoize. There are currently no options yet.
 
 See L<Memoize> for more information and caveats about memoizing.
 
-=head1 SEE ALSO
-
-L<Perinci>
-
-L<Memoize>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Sub-Property-memoize>.
@@ -103,13 +99,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Perinci>
+
+L<Memoize>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
